/*
   math/vector2f.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include <cstring>
#include <cmath>

#include "math/vector2f.h"

namespace math
{

Vector2f::Vector2f() : x(coord[0]), y(coord[1])
{
	clear();
}

Vector2f::Vector2f(const Vector2f &other) : x(coord[0]), y(coord[1])
{
	assign(other);
}

Vector2f::Vector2f(const float x, const float y) : x(coord[0]), y(coord[1])
{
	assign(x, y);
}

void Vector2f::clear()
{
	memset(coord, 0, sizeof(coord));
}

void Vector2f::assign(const Vector2f &other)
{
	memcpy(coord, other.coord, sizeof(coord));
}

void Vector2f::assign(const float x, const float y)
{
	coord[0] = x;
	coord[1] = y;
}

Vector2f &Vector2f::operator=(const Vector2f &other)
{
	assign(other);
	return (*this);
}

Vector2f &Vector2f::operator+=(const Vector2f &other)
{
	coord[0] += other.coord[0];
	coord[1] += other.coord[1];
	return (*this);
}

Vector2f &Vector2f::operator-=(const Vector2f &other)
{
	coord[0] -= other.coord[0];
	coord[1] -= other.coord[1];
	return (*this);
}

float distance(const Vector2f& first, const Vector2f& second)
{
	float r = 0;
	for (int i=0; i < 2; i++)
		r += (first[i]-second[i])*(first[i]-second[i]);
		
	return (sqrtf(r));
}

float distancesquared(const Vector2f& first, const Vector2f& second)
{
	float r = 0;
	for (int i=0; i < 2; i++)
		r += (first[i]-second[i])*(first[i]-second[i]);
	return (r);
}

}
