/*
   model/plane.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include <string>

#include "model/plane.h"

namespace model
{

using math::Vector3f;
/*
 *  all points p(x, y, z) on the plane satisfy the general equation
 *  x*a() + y*b() + z*c() + d() = 0
 */

Plane::Plane(Vector3f const & point0, Vector3f const &point1, Vector3f const &point2)
{
	plane_detail = false;
	plane_surface_flags = 0;
	
	plane_point[0] = point0;
	plane_point[1] = point1;
	plane_point[2] = point2;
	
	plane_normal = crossproduct((plane_point[1] - plane_point[0]) , (plane_point[2] - plane_point[0]));
	pd = -1 * (plane_normal.x * plane_point[0].x + plane_normal.y * plane_point[0].y + plane_normal.z * plane_point[0].z);
}

Plane::Plane(Plane const & other)
{
	for (size_t i=0; i < 3; i++)
		this->plane_point[i] = other.plane_point[i];
		
	plane_normal = crossproduct((plane_point[1] - plane_point[0]) , (plane_point[2] - plane_point[0]));
	pd = -1 * (plane_normal.x * plane_point[0].x + plane_normal.y * plane_point[0].y + plane_normal.z * plane_point[0].z);
}

}
