/*
   ui/palette.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#ifndef __INCLUDED_UI_PALETTE_H__
#define __INCLUDED_UI_PALETTE_H__

#include "math/color.h"

namespace ui
{

class Palette
{

public:
	Palette();
	~Palette();
	
	enum Color { Foreground=0, Background=1, Highlight=2, Border=3, Pointer=4, Active=5, Debug=6 };

	/// set foreground color
	void set_foreground(math::Color const &color);
	
	/// set highlight color
	void set_highlight(math::Color const &color);

	void set_text(math::Color const &color);
	
	void set_background(math::Color const &color);
	
	void set_border(math::Color const &color);
	
	void set_pointer(math::Color const &color);
	
	void set_active(math::Color const &color);

	void set_debug(math::Color const &olor);
	
	inline const math::Color &foreground() const {
		return palette_foreground;
	}
	
	inline const math::Color &highlight() const {
		return palette_highlight;
	}

	inline const math::Color &text() const {
		return palette_text;
	}
	
	inline const math::Color &background() const {
		return palette_background;
	}
	
	inline const math::Color &border() const {
		return palette_border;
	}
	
	inline const math::Color &pointer() const {
		return palette_pointer;
	}
	
	inline const math::Color &active() const {
		return palette_active;
	}

	inline const math::Color &debug() const {
		return palette_debug;
	}

	const math::Color &color(Palette::Color palettecolor) const;
	
private:

	math::Color	palette_foreground;
	math::Color	palette_highlight;
	math::Color	palette_background;
	math::Color	palette_pointer;
	math::Color	palette_active;
	math::Color	palette_border;
	math::Color	palette_debug;
	math::Color	palette_text;
};

}

#endif // __INCLUDED_UI_PALETTE_H__

